
/******************************************************************************
* MODULE     : base.cpp
* DESCRIPTION: Basic inclusions, definitions and routines
* COPYRIGHT  : (C) 2003  Joris van der Hoeven
*******************************************************************************
* This software falls under the GNU general public license and comes WITHOUT
* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
* If you don't have this file, write to the Free Software Foundation, Inc.,
* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/

#include "base.hpp"
#include <gmp.h>
#include <mpfr.h>
namespace mml {

volatile void
fatal_error (char* message, char* routine, char* file) {
  cout << "\nFatal error: " << message
       << "\n             in '" << routine
       << "' in file '" << file << "'\n";
  exit (1);
}

static void*
mml_realloc (void* ptr, size_t old_size, size_t new_size) {
  (void) old_size;
  return GC_realloc (ptr, new_size);
}

static void
mml_free (void* ptr, size_t old_size) {
  (void) ptr; (void) old_size;
}

void
mml_init () {
  mp_set_memory_functions (GC_malloc, mml_realloc, mml_free);
  mpfr_set_default_rounding_mode (GMP_RNDN);
  mpfr_set_default_prec (__GMP_BITS_PER_MP_LIMB << 1);
}

} // namespace mml
